@@ -1,5 +1,4 @@
 use clap::Args;
-use color_eyre::eyre::ErrReport;
 use zeroize::Zeroize;
 
 use crate::{otp::otp_element::OTPDatabase, utils};
@@ -12,9 +11,7 @@ pub struct PasswdArgs;
 impl SubcommandExecutor for PasswdArgs {
     fn run_command(self, mut database: OTPDatabase) -> color_eyre::Result<OTPDatabase> {
         let mut new_password = utils::verified_password("New password: ", 8);
-        database
-            .save_with_pw(&new_password)
-            .map_err(ErrReport::from)?;
+        database.save_with_pw(&new_password)?;
         new_password.zeroize();
         Ok(database)
     }
